% ------------------------------
% ------------------------------
% Table MLE - 2SLS -------------
% ------------------------------
% ------------------------------

clear
Data = csvread('ADD_Mafia_matlab.csv', 1,0);
W = Data(:,64:102);
rng(1111)

% Defining variables:

Mafia=Data(:,8);
Rain=Data(:,10);
Dist=Data(:,63);

% Defining outcome variables:
lit_mf1911=Data(:,33);
lit_mf1921=Data(:,34);
lit_mf1931=Data(:,35);
infant1909=Data(:,44);
dev_spending1912=Data(:,42);
notaries1924=Data(:,47);
hhi1909=Data(:,51);
high_mf1961=Data(:,39);
high_mf1971=Data(:,40);
high_mf1981=Data(:,41);
lit_mf1961=Data(:,36);
lit_mf1971=Data(:,37);
lit_mf1981=Data(:,38);
infmort1969_70=Data(:,45);
infmort1982=Data(:,46);
dev_spending1957=Data(:,43);
drink1961=Data(:,48);
drink1971=Data(:,49);
drink1981=Data(:,50);
hhi1963=Data(:,52);
hhi1972=Data(:,53);
hhi1983=Data(:,54);


Outcomes=[lit_mf1911, lit_mf1921, lit_mf1931, infant1909, dev_spending1912, notaries1924, hhi1909, high_mf1961, high_mf1971, high_mf1981, lit_mf1961, lit_mf1971,...
         lit_mf1981, infmort1969_70, infmort1982, dev_spending1957, drink1961, drink1971, drink1981, hhi1963, hhi1972, hhi1983];
      
% Looping over outcomes:
save main9.mat;
jj=0;

for j=1:22
  
    % -------------------------------------
    %  Province + Fasci + Mafia + Geo/Demo:
    % -------------------------------------
    
    load main9.mat;
    outcome=Outcomes(:,j);
    jj=jj+1;
 
   % Fasci Controls:
    [n]=size(Data,1);
    X=[ones(n,1), Data(:,11), Data(:,12), Data(:,13),Data(:,14), Data(:,15), Data(:,16)] ;

    % Provinces:

    X=[X, Data(:,1:7)];
    
    % Mafia Controls:

    X=[X, Data(:,17), Data(:,18), Data(:,19), Data(:,20), Data(:,21)];

    % Geo/Demo Controls:

    X=[X, Data(:,22), Data(:,23), Data(:,24), Data(:,25), Data(:,26), ...
        Data(:,27), Data(:,28), Data(:,29), Data(:,30), Data(:,31), Data(:,32)];
    
    % Droping missing values:

    [n,p]=size(X)
    M=[outcome,Mafia, Rain, Dist, X, W];
    M=M(find(sum(isnan(M),2)==0),:);
    
    outcome=M(:,1);
    Mafia=M(:,2);
    Rain=M(:,3);
    Dist=M(:,4);
    X=M(:,5:(p+4));
    W=M(:,(p+5):size(M,2));
    
    % Dropping colinear covariates:
    X=licols(X);

    % IV Estimation:
    
    [n,p]=size(X);
    p0=zeros(2*p+6,1);
    XX=[Rain, X];
    p0(1:p+1)=inv(XX'*XX)*XX'*Mafia;

    m_hat= XX*inv(XX'*XX)*XX'*Mafia;
    XX=[m_hat, X];
    p0(p+2:2*p+2) =inv(XX'*XX)*XX'*outcome;
    p0(2*p+3:2*p+5)=-2.5;
    
    [param,~,exitflag] = knitromatlab(@(theta)TS_RE_ML(theta,outcome, Rain, X,W,Mafia),p0,[],[],[],[],[],[],[],[],[], 'knitro.opt.txt') 
    [se_d, error] =WBS_ClusterDist_TSRest(param,outcome, Rain, X,W,Mafia,Dist,p0,800)

    save(strcat('table_LR_A_',num2str(jj),'.mat'));
end