## --------------------------------- ##
## IV Beliefs on Medium Run Outcomes ## 
## --------------------------------- ##


rm(list=ls())
install.packages("devtools")
library(devtools)
install_github("fditraglia/ivdoctr")

library(rvest)
library(tidyverse)
library(modelr)
library(gdata)
library(stargazer)
library(AER)
library(lmtest)
setwd("...\non Stata") 

# Defining controls:

prov_ctr=c("province1","province2","province3","province4", "province5", "province6", "province7")
fasci_ctr=c(prov_ctr, "predr_peas_fasci", "ruralcentre1861", "Rural_rent", "Urban_rent", "agricola_rel", "seminatoritot_rel")
mafia_ctr=c(fasci_ctr,"sulfurproduction1868_70", "Citrus_groves", "Vineyards", "Olives_groves", "Mafia1885")
full_ctr=c(mafia_ctr,"lnpop1861", "lnsurface", "centreheight", "maxheight", "slope2",
           "pa_pdist1856", "port2_pdist1856", "roads1799", "ave_temp", "var_sp3m_n30", "sp3m_ave_n30")

# Looping over positive correlation variables:

outcomes <- c("lit_mf1911", "lit_mf1921", "lit_mf1931", "dev_spending1912", "notaries1924","lit_mf1961", "lit_mf1971", "lit_mf1981", "high_mf1961", "high_mf1971","high_mf1981","drink1961","drink1971","drink1981", "dev_spending1957")

set.seed(1111)
for(outcome in outcomes){
Dt <- read.csv("ADD_Mafia_matlab.csv")
var_2_keep<-c(outcome, "Mafia1900", "sp3m1893_n30", full_ctr)
Data<-na.omit(Dt[var_2_keep])
  K1 <- ivdoctr:::makeExample(outcome,"Mafia1900","sp3m1893_n30",Data,
                                                 controls =full_ctr , robust = TRUE,
                                                 r_TstarU_restriction =  matrix(c(0.1, 0.9), nrow = 1), 
                                                k_restriction= matrix(c(0.5, 1), nrow = 1), 
                                                n_draws = 5000, n_RF_draws = 1000, 
                                                n_IS_draws = 1000, resample = FALSE, outcome)

ivdoctr:::makeTable(paste(outcome,".tex"), binary = FALSE, K1)
}


# Looping over negative correlation variables:


outcomes <- c("infant1909","infmort1969_70","infmort1982","hhi1909","hhi1963","hhi1972","hhi1983")

set.seed(1111)

for(outcome in outcomes){
Dt <- read.csv("ADD_Mafia_matlab.csv")
var_2_keep<-c(outcome, "Mafia1900", "sp3m1893_n30", full_ctr)
Data<-na.omit(Dt[var_2_keep])

  K1 <- ivdoctr:::makeExample(outcome, "Mafia1900", "sp3m1893_n30", Data, controls =full_ctr , robust = TRUE,
                             r_TstarU_restriction =  matrix(c(-0.1, -0.9), nrow = 1), k_restriction= matrix(c(0.5, 1), nrow = 1), n_draws = 5000,
                             n_RF_draws = 1000, n_IS_draws = 1000, resample = FALSE, outcome)
  
  ivdoctr:::makeTable(paste(outcome,".tex"), binary = FALSE, K1)
}

