function [boot_cov_clust_2W,boot_cov_clust_Dist,boot_cov_clust_Close,boot_cov_clust_Inter, b_FS1, b_RF1] = WBS_ClusterDist_Corr(y, Z, X,W,M,Dist,reps)

XX=[Z,X];
[n,p]=size(XX);
[n,k]=size(W);

% ------------------------ %
% Using District Clusters: %
% ------------------------ %

b_FS= XX\M;
b_FS1=b_FS(1,1);
b_RF=[Z,X]\y;
b_RF1=b_RF(1,1);

% Computing corrected standard errors:

e_FS=(M-XX*b_FS)*(n/(n-p))^0.5;
e_RF=(y-[Z,X]*b_RF)*(n/(n-p))^0.5;

B = reps;

% Getting indicator variable for clusters:

e_FS=[e_FS,Dist];
e_RF=[e_RF,Dist];
I=Dist;
UI=unique(Dist);
d=size(UI,1);

% Initialize BStar
B_FS_Star = zeros(B,1);
B_RF_Star = zeros(B,1);

% Loop over B bootstraps
parfor bb=1:B
    
% residual sample simulation

e_FS_clust=zeros(n,1);
e_RF_clust=zeros(n,1);

prob = 0.5;

for i=1:d
    ii=UI(i);
    Ik= find(e_FS(:,2)==ii);
    h=rand(1);
    J=(h < prob) -(h > prob);
    e_FS_clust(Ik)=J*e_FS((I==ii),1);
    e_RF_clust(Ik)=J*e_RF((I==ii),1);
end

MStar=XX*b_FS+e_FS_clust;
yStar =[Z,X]*b_RF+e_RF_clust;

% Coeff:
b_FS_bs=XX\MStar;
b_RF_bs=[Z,X]\yStar;


B_FS_Star(bb,1)= b_FS_bs(1,1);
B_RF_Star(bb,1) = b_RF_bs(1,1);
end

boot_cov_clust_Dist=cov([B_FS_Star,B_RF_Star]);


% ------------------------------- %
% Using Closest Station Clusters: %
% ------------------------------- %

b_FS= XX\M;
b_RF=[Z,X]\y;

e_FS=(M-XX*b_FS)*(n/(n-p))^0.5;
e_RF=(y-[Z,X]*b_RF)*(n/(n-p))^0.5;

B = reps;

% Getting indicator variable for clusters:

[M,I]=max(W,[],2);
e_FS=[e_FS,I];
e_RF=[e_RF,I];
UI=unique(I);
d=size(UI,1);

% Initialize BStar
B_FS_Star = zeros(B,1);
B_RF_Star = zeros(B,1);

% Loop over B bootstraps
parfor bb=1:B

% residual sample simulation

e_FS_clust=zeros(n,1);
e_RF_clust=zeros(n,1);

prob = 0.5;

for i=1:d
    ii=UI(i);
    Ik= find(e_FS(:,2)==ii);
    h=rand(1);
    J=(h < prob) -(h > prob);
    e_FS_clust(Ik)=J*e_FS((I==ii),1);
    e_RF_clust(Ik)=J*e_RF((I==ii),1);
end

MStar=XX*b_FS+e_FS_clust;
yStar =[Z,X]*b_RF+e_RF_clust;

% Coeff:
b_FS_bs=XX\MStar;
b_RF_bs=[Z,X]\yStar;

B_FS_Star(bb,1)= b_FS_bs(1,1);
B_RF_Star(bb,1) = b_RF_bs(1,1);
end

boot_cov_clust_Close=cov([B_FS_Star,B_RF_Star]);

% ------------------------------- %
% Using Intersection of Clusters: %
% ------------------------------- %

b_FS= XX\M;
b_RF=[Z,X]\y;

e_FS=(M-XX*b_FS)*(n/(n-p))^0.5;
e_RF=(y-[Z,X]*b_RF)*(n/(n-p))^0.5;

B = reps;

% Getting indicator variable for closest station clusters:
[M,I]=max(W,[],2);

% Getting unique intersection of clusters:

[~,~,Clust] = unique([Dist(:) I(:)],'rows')

e_FS=[e_FS,Clust];
e_RF=[e_RF,Clust];
UI=unique(Clust);
d=size(UI,1);

% Initialize BStar
B_FS_Star = zeros(B,1);
B_RF_Star = zeros(B,1);

% Loop over B bootstraps
parfor bb=1:B

% residual sample simulation

e_FS_clust=zeros(n,1);
e_RF_clust=zeros(n,1);

prob = 0.5;

for i=1:d
    ii=UI(i);
    Ik= find(e_FS(:,2)==ii);
    h=rand(1);
    J=(h < prob) -(h > prob);
    e_FS_clust(Ik)=J*e_FS((Clust==ii),1);
    e_RF_clust(Ik)=J*e_RF((Clust==ii),1);
end

MStar=XX*b_FS+e_FS_clust;
yStar =[Z,X]*b_RF+e_RF_clust;

% Coeff:
b_FS_bs=XX\MStar;
b_RF_bs=[Z,X]\yStar;

B_FS_Star(bb,1)= b_FS_bs(1,1);
B_RF_Star(bb,1) = b_RF_bs(1,1);
end

boot_cov_clust_Inter=cov([B_FS_Star,B_RF_Star]);

boot_cov_clust_2W=boot_cov_clust_Dist+boot_cov_clust_Close-boot_cov_clust_Inter;
end